@@ -62,10 +62,10 @@ class TestResource(unittest.TestCase):
 
     def test_resource_has_a_size_property(self):
         test_env_dir = tempfile.mkdtemp()
-        test_file_path = os.path.join(test_env_dir, 'test_file.txt')
-        helpers.create_file_with_content(test_file_path, 'some\ttext\non two lines')
+        test_file_path = os.path.join(test_env_dir, 'test_file.js')
+        helpers.create_file_with_content(test_file_path, '//some\ttext\non two lines')
         resource = Resource(test_file_path)
-        self.assertEqual(22, resource.size)
+        self.assertEqual(24, resource.size)
         shutil.rmtree(test_env_dir)
 
     def test_resource_has_an_extension_property(self):
@@ -99,6 +99,7 @@ class TestResource(unittest.TestCase):
             ('/usr/local/file.js',       'file'),
             ('FILE.JS',                  'file'),
             ('some-Plugin-2.3.2-min.js', 'some-plugin'),
+            ('some-dashed-file-name.js', 'some-dashed-file-name'),
             ('jQuery-1.2.3.js',          'jquery')]
         for test_file_path, expected_base_name in test_file_paths_and_expected_base_names:
             resource = Resource(test_file_path)
